"use client"

import LoadingItem from "@/components/loading-item"
import { TryAgain } from "@/components/try-again"
import { User } from "next-auth"
import { usePathname } from "next/navigation"
import { useGetFollows } from "../hooks/use-get-follows"
import { UserItem } from "./user-item"

export const UserFollows = ({ username, session }: { username: string, session: User | undefined }) => {
    const pathValue = usePathname().split("/")[2] || ""

    const {
        data: following,
        isLoading,
        isError,
    } = useGetFollows({
        id: username,
        type: pathValue,
    })

    if (isLoading) {
        return (
            <LoadingItem />
        )
    }

    if (isError || !following) {
        return (
            <TryAgain />
        )
    }

    if (following?.length === 0) {
        if (session?.username === username) {
            return (
                <div className="m-6 flex justify-center">
                    <div className="font-bold">
                        {pathValue === "following" ?
                            <>
                                <h1>You are not following anyone.</h1>
                                <p>When you do, it&apos;ll show up here.</p>
                            </>
                            :
                            <>
                                <h1>You have no followers.</h1>
                                <p>When you do, they&apos;ll show up here.</p>
                            </>
                        }
                    </div>
                </div>
            )
        }
        return (
            <div className="m-6 flex justify-center">
                <div className="font-bold">
                    {pathValue === "following" ?
                        <>
                            <h1><span className="text-sky-500">@{username}</span> is not following anyone yet.</h1>
                            <p>When they do, it&apos;ll show up here.</p>
                        </>
                        :
                        <>
                            <h1><span className="text-sky-500">@{username}</span> has no followers.</h1>
                            <p>When they do, they&apos;ll show up here.</p>
                        </>
                    }
                </div>
            </div>
        )
    }

    return (
        <div className="space-y-5 flex flex-col">
            {following?.map((user) => {
                return <UserItem key={user?.id} user={user} sessionId={session?.id} />
            })}
        </div>
    )
}